/*************************************************************** 
 * Atmega32 SImple OS
 * Walter Schilling, Instructor
 * September, 2011
 *
 * This file contains the interface for a very simple
 * embedded operating system.  In essence, it provides for a simple,
 * round robin scheduler based upon timer 0.
 * Processes may be stopped and started at will by the user.
 ***************************************************************
 */


#ifndef OS_H
#define OS_H

// This definition provides the stack size for each process.
// It is given in bytes.
#define STACKSIZE (128)

// This is the starting address for stack.
extern unsigned int __STACK_TOP;
#define STACKSTART (&__STACK_TOP)

// These variables define the states for various processes.
#define NEW (1)
#define RUNNING (2)
#define BLOCKED (-1)
#define UNINITIALZED (0)

// This definition defines the maximum number of processes which are allowed to execute at once.
#define MAXNUMBEROFPROCESSES (0x04)

#define NULL (void*)(0)

/*************************************************************** 
 * This method will start the operation of the OS.  The process 
 * control blocks will be initialized, and the calling process 
 * will be given process block 0.
 *
 ***************************************************************/
void startOS();

/*************************************************************** 
 * addProcess
 * This method will add a new process to the OS.  The process
 * is passed in as a void pointer.
 *
 * Parameters:
 *  function (void*) This is the function which is to be the new process.
 * Return
 * The methdo will return the assigned process id (pid) or
 * -1 if the process can not be added. 
 *
 ***************************************************************/
int8_t addProcess(void* function);

/*************************************************************** 
 * terminateProcess
 * This method will terminate an active process.
 *
 * Parameters:
 *  pid (int8_t) This is the pid for the process that is to be terminated.
 * Return
 *  None
 ***************************************************************/
void terminateProcess(int8_t pid);

#endif





